@@ -75,6 +75,9 @@ class TestApiIntrospect(BaseAPITest):
                                                       node_id=self.uuid,
                                                       manage_boot=True,
                                                       token=None)
+        self.assertEqual('application/json',
+                         res.headers['content-type'])
+        self.assertEqual(b'{}\n', res.data)
 
     def test_intospect_failed(self):
         self.client_mock.call.side_effect = utils.Error("boom")
@@ -98,6 +101,9 @@ class TestApiIntrospect(BaseAPITest):
                                                       node_id=self.uuid,
                                                       manage_boot=False,
                                                       token=None)
+        self.assertEqual('application/json',
+                         res.headers['content-type'])
+        self.assertEqual(b'{}\n', res.data)
 
     def test_introspect_can_manage_boot_false(self):
         CONF.set_override('can_manage_boot', False)
@@ -204,7 +210,9 @@ class TestApiAbort(BaseAPITest):
                                                       node_id=self.uuid,
                                                       token='token')
         self.assertEqual(202, res.status_code)
-        self.assertEqual(b'', res.data)
+        self.assertEqual(b'{}\n', res.data)
+        self.assertEqual('application/json',
+                         res.headers['content-type'])
 
     def test_no_authentication(self):
 
@@ -214,7 +222,9 @@ class TestApiAbort(BaseAPITest):
                                                       node_id=self.uuid,
                                                       token=None)
         self.assertEqual(202, res.status_code)
-        self.assertEqual(b'', res.data)
+        self.assertEqual(b'{}\n', res.data)
+        self.assertEqual('application/json',
+                         res.headers['content-type'])
 
     def test_node_not_found(self):
         exc = utils.Error("Not Found.", code=404)
@@ -361,6 +371,19 @@ class TestApiGetData(BaseAPITest):
         self.assertEqual(self.introspection_data,
                          json.loads(res.data.decode('utf-8')))
 
+    @mock.patch.object(swift, 'SwiftAPI', autospec=True)
+    def test_get_unprocessed_data_from_swift(self, swift_mock):
+        CONF.set_override('store_data', 'swift', 'processing')
+        swift_conn = swift_mock.return_value
+        swift_conn.get_object.return_value = json.dumps(
+            self.introspection_data)
+        res = self.app.get('/v1/introspection/%s/data/unprocessed' % self.uuid)
+        name = 'inspector_data-%s-UNPROCESSED' % self.uuid
+        swift_conn.get_object.assert_called_once_with(name)
+        self.assertEqual(200, res.status_code)
+        self.assertEqual(self.introspection_data,
+                         json.loads(res.data.decode('utf-8')))
+
     @mock.patch.object(intros_data_plugin, 'DatabaseStore',
                        autospec=True)
     def test_get_introspection_data_from_db(self, db_mock):
@@ -379,6 +402,11 @@ class TestApiGetData(BaseAPITest):
         res = self.app.get('/v1/introspection/%s/data' % self.uuid)
         self.assertEqual(404, res.status_code)
 
+    def test_unprocessed_data_not_stored(self):
+        CONF.set_override('store_data', 'none', 'processing')
+        res = self.app.get('/v1/introspection/%s/data/unprocessed' % self.uuid)
+        self.assertEqual(404, res.status_code)
+
     @mock.patch.object(ir_utils, 'get_node', autospec=True)
     @mock.patch.object(main.process, 'get_introspection_data', autospec=True)
     def test_with_name(self, process_mock, get_mock):
@@ -567,6 +595,8 @@ class TestApiRules(BaseAPITest):
         res = self.app.delete('/v1/rules/' + self.uuid)
         self.assertEqual(204, res.status_code)
         delete_mock.assert_called_once_with(self.uuid)
+        self.assertEqual('text/plain; charset=utf-8',
+                         res.headers['content-type'])
 
 
 class TestApiMisc(BaseAPITest):
